################################################################################################################################
#
# Description:	This constraint file applies to hardware features that are unique to a specific model number within a
#				product family.
#
# Rev History: 	04-10-2017:	Inital release.
#
################################################################################################################################

###################################################### Timing Constraints ######################################################

# Set the RX1 clock frequency to 125 MHz
create_clock -period 8.000 -name rx_clk [get_ports sample_clk_p]
set_clock_groups -name async_rx_clk -asynchronous -group [get_clocks rx_clk]

# Set the clock forward (DCO) frequencies to 500 MHz
create_clock -period 2.000 -name rx1to4_clk [get_ports rx1to4_clk_in_p]
set_clock_groups -name async_rx1to4_clk -asynchronous -group [get_clocks rx1to4_clk]
create_clock -period 2.000 -name rx1to4_clkb [get_ports rx1to4_clkb_in_p]
set_clock_groups -name async_rx1to4_clbk -asynchronous -group [get_clocks rx1to4_clkb]
create_clock -period 2.000 -name rx5to8_clk [get_ports rx5to8_clk_in_p]
set_clock_groups -name async_rx5to8_clk -asynchronous -group [get_clocks rx5to8_clk]
create_clock -period 2.000 -name rx5to8_clkb [get_ports rx5to8_clkb_in_p]
set_clock_groups -name async_rx5to8_clkb -asynchronous -group [get_clocks rx5to8_clkb]

# Set the frame (FCO) frequencies to 125 MHz
create_clock -period 8.000 -name rx1to4_frame [get_ports rx1to4_frame_in_p]
set_clock_groups -name async_rx1to4_frame -asynchronous -group [get_clocks rx1to4_frame]
create_clock -period 8.000 -name rx5to8_frame [get_ports rx5to8_frame_in_p]
set_clock_groups -name async_rx5to8_frame -asynchronous -group [get_clocks rx5to8_frame]

# Set a false path to the frame input buffer used for dynamic phase alignment.
set_false_path -through [get_pins {XCVR/RX_CH.ADC/ADC_FRAME[1].FFWD_DDR/C}]
set_false_path -through [get_pins {XCVR/RX_CH.ADC/ADC_FRAME[2].FFWD_DDR/C}]

###################################################### Pinout Constraints ######################################################
# Note: The external component and pin name connected to each PACKAGE_PIN is shown as a comment (#component:pin).

# Sample clock generated by the frequency synthesizer.
set_property PACKAGE_PIN G22 [get_ports sample_clk_p];  #AD9512:CLKOUT0P

# RX1 pin assignments.
set_property PACKAGE_PIN AD26 [get_ports {rx1_data_in_p[0]}];  #AD9653:D0+A
set_property PACKAGE_PIN AD25 [get_ports {rx1_data_in_p[1]}];  #AD9653:D1+A

# RX2 pin assignments.
set_property PACKAGE_PIN AB26 [get_ports {rx2_data_in_p[0]}];  #AD9653:D0+B
set_property PACKAGE_PIN AA25 [get_ports {rx2_data_in_p[1]}];  #AD9653:D1+B

# RX3 pin assignments.
set_property PACKAGE_PIN Y25 [get_ports {rx3_data_in_p[0]}];  #AD9653:D0+C
set_property PACKAGE_PIN W25 [get_ports {rx3_data_in_p[1]}];  #AD9653:D1+C

# RX4 pin assignments.
set_property PACKAGE_PIN U24 [get_ports {rx4_data_in_p[0]}];  #AD9653:D0+D
set_property PACKAGE_PIN U26 [get_ports {rx4_data_in_p[1]}];  #AD9653:D1+D

# RX1 to RX4 frame pin assignment.
set_property PACKAGE_PIN Y22 [get_ports rx1to4_frame_in_p];  #AD9653:FCO+
set_property PACKAGE_PIN V21 [get_ports rx1to4_ffwd_in_p];  #AD9653:FCO+

# RX1 to RX4 clock forward pin assignment.
set_property PACKAGE_PIN AA23 [get_ports rx1to4_fwd_in_p];  #AD9653:DCO+
set_property PACKAGE_PIN Y23 [get_ports rx1to4_clk_in_p];  #AD9653:DCO+
set_property PACKAGE_PIN AC23 [get_ports rx1to4_clkb_in_p];  #AD9653:DCO+

# RX5 pin assignments.
set_property PACKAGE_PIN T24 [get_ports {rx5_data_in_p[0]}];  #AD9653:D0+A
set_property PACKAGE_PIN T22 [get_ports {rx5_data_in_p[1]}];  #AD9653:D1+A

# RX6 pin assignments.
set_property PACKAGE_PIN R26 [get_ports {rx6_data_in_p[0]}];  #AD9653:D0+B
set_property PACKAGE_PIN R25 [get_ports {rx6_data_in_p[1]}];  #AD9653:D1+B

# RX7 pin assignments.
set_property PACKAGE_PIN N26 [get_ports {rx7_data_in_p[0]}];  #AD9653:D0+C
set_property PACKAGE_PIN M25 [get_ports {rx7_data_in_p[1]}];  #AD9653:D1+C

# RX8 pin assignments.
set_property PACKAGE_PIN M24 [get_ports {rx8_data_in_p[0]}];  #AD9653:D0+D
set_property PACKAGE_PIN K25 [get_ports {rx8_data_in_p[1]}];  #AD9653:D1+D

# RX5 to RX8 frame pin assignment.
set_property PACKAGE_PIN R21 [get_ports rx5to8_frame_in_p];  #AD9653:FCO+
set_property PACKAGE_PIN T20 [get_ports rx5to8_ffwd_in_p];  #AD9653:FCO+

# RX5 to RX8 clock forward pin assignment.
set_property PACKAGE_PIN R22 [get_ports rx5to8_fwd_in_p];  #AD9653:DCO+
set_property PACKAGE_PIN N21 [get_ports rx5to8_clk_in_p];  #AD9653:DCO+
set_property PACKAGE_PIN P23 [get_ports rx5to8_clkb_in_p];  #AD9653:DCO+

# RX multichip sync pin assignment.
set_property PACKAGE_PIN V23 [get_ports rx_sync_out_p];  #AD9653:SYNC+
